@@ -116,14 +116,14 @@ def signal_handler(signum, frame, verbose=False):
 def _read_data(stream, ostr1, ostr2):
     while True:
         data = os.read(stream, 80)
-        if sys.stdout.encoding is None:
+        if sys.__stdout__.encoding is None:
             data = data.decode('utf-8')
         else:
-            data = data.decode(sys.stdout.encoding)
+            data = data.decode(sys.__stdout__.encoding)
         if data:
             ostr1.write(data)
-            ostr2.write(data)
             ostr1.flush()
+            ostr2.write(data)
             ostr2.flush()
         else:
             break
@@ -200,7 +200,10 @@ def run_command(cmd, outfile=None, cwd=None, ostream=None, stdin=None, stdout=No
         stderr_arg=stderr
         output = "Output printed to specified stdout and stderr streams"
     else:
-        tmpfile = tempfile.TemporaryFile()
+        # Create a temporary file.  The mode is w+, which means that we can read and write.
+        # NOTE: the default mode is w+b, but writing to the binary mode seems to cause problems
+        # in the _read_data function on Python 3.x.
+        tmpfile = tempfile.TemporaryFile(mode='w+')
         stdout_arg=tmpfile
         stderr_arg=tmpfile
         output=""
