@@ -35,6 +35,7 @@ class Test(unittest.TestCase):
         print("Ran for %f seconds" % (timer()-stime))
 
     @unittest.skipIf(subprocess.mswindows, "Cannot test the use of 'memmon' on MS Windows")
+    @unittest.skipIf(sys.platform == 'darwin', "Cannot test the use of 'memmon' on Darwin")
     @unittest.skipIf(pyutilib.services.registered_executable('memmon') is None, "The 'memmon' executable is not available.")
     def test_memmon(self):
         pyutilib.services.register_executable('ls')
@@ -66,6 +67,16 @@ class Test(unittest.TestCase):
             self.fail("Failed to properly execute 'valgrind' with the 'ls' command")
         os.remove(currdir+'valgrind.out')
         
+    def test_outputfile(self):
+        pyutilib.subprocess.run([sys.executable, currdir+"tee_script.py"], outfile=currdir+'tee.out')
+        self.assertFileEqualsBaseline(currdir+'tee.out', currdir+'tee.txt')
+
+    def test_tee(self):
+        pyutilib.misc.setup_redirect(currdir+'tee.stream')
+        output = pyutilib.subprocess.run([sys.executable, currdir+"tee_script.py"], outfile=currdir+'tee.out', tee=True)
+        pyutilib.misc.reset_redirect()
+        self.assertFileEqualsBaseline(currdir+'tee.out', currdir+'tee.txt')
+
 
 if __name__ == "__main__":
     unittest.main()
